declare const nw: any;

import "reflect-metadata";
import "zone.js";
import "tslib";
import * as SourceMapSupport from "source-map-support";
import App from "./app";

const fs = nw.require("fs");
const path = nw.require("path");

export default class Bootstrap
{
    private static isBooted: boolean = false;

    private static async patchErrorStack(): Promise<void>
    {
        SourceMapSupport.install({
            retrieveSourceMap: (source) => {
                const mapFile: string = path.resolve(nw.process.cwd(), "dist/app.bundle.js.map");
                return {
                    url: source,
                    map: fs.readFileSync(mapFile, "utf8")
                };
            }
        });
    }

    public static async init(): Promise<void>
    {
        if (Bootstrap.isBooted === true) {
            throw new Error("Application is already booted.");
        }
        await Bootstrap.patchErrorStack();
        try {
            await new App().startup();
        } catch (error) {
            console.error(error.message, error.stack);
        }
        Bootstrap.isBooted = true;
    }
};

(async (): Promise<void> => {
    await Bootstrap.init();
})();